# This file has been generated


build_system = 'AppVeyor'
build_id = '31957355'
build_number = '641'
build_version = '1.0.641'
job_id = 'lr2o7b21bs9efxc8'
job_url = 'https://ci.appveyor.com/project/KyleAltendorf/pm/build/job/lr2o7b21bs9efxc8'



# This file was automatically generated by sub\epyqlib\epyqlib\cli\generateversion.py
__version_build_time__ = '2020-04-04T23:13:03.885156'

__version__ = '2020.4.2'
__sha__ = '529c5cf8c439eaa4e01ddac8b8dae76edfcc5a1c'
__revision__ = '529c5cf8c439eaa4e01ddac8b8dae76edfcc5a1c'
